@@ -1,7 +1,7 @@
 /*
-   $Id: Pg.h,v 1.13 2006/01/30 03:11:56 turnstep Exp $
+   $Id: Pg.h 10520 2008-01-11 19:01:08Z turnstep $
 
-   Copyright (c) 2000-2006 PostgreSQL Global Development Group
+   Copyright (c) 2000-2008 Greg Sabino Mullane and others: see the Changes file
    Copyright (c) 1997-2000 Edmund Mergl
    Portions Copyright (c) 1994-1997 Tim Bunce
 
@@ -17,6 +17,9 @@ static int errno;
 
 #define DBDPG_TRUE (bool)1
 #define DBDPG_FALSE (bool)0
+#define PG_ASYNC 1
+#define PG_OLDQUERY_CANCEL 2
+#define PG_OLDQUERY_WAIT 4
 
 #include "libpq-fe.h"
 
@@ -31,11 +34,6 @@ static int errno;
 #define INV_WRITE 0x00020000
 #endif
 
-/* For versions of DBI older than 1.41 */
-#ifndef DBIcf_Executed
-#define DBIcf_Executed 0x080000
-#endif
-
 #ifdef BUFSIZ
 #undef BUFSIZ
 #endif
